@@ -245,12 +245,12 @@ class HDXObject(UserDict, object):
             self.data['batch_mode'] = kwargs['batch_mode']
         if 'skip_validation' in kwargs:  # Whether or not CKAN should perform validation steps (checking fields present)
             self.data['skip_validation'] = kwargs['skip_validation']
-        ignore_fields = list()
+        ignore_fields = kwargs.get('ignore_fields', list())
         ignore_field = self.configuration[object_type].get('ignore_on_update')
-        if ignore_field:
+        if ignore_field and ignore_field not in ignore_fields:
             ignore_fields.append(ignore_field)
         ignore_field = kwargs.get('ignore_field')
-        if ignore_field:
+        if ignore_field and ignore_field not in ignore_fields:
             ignore_fields.append(ignore_field)
         if 'ignore_check' not in kwargs or not kwargs.get('ignore_check'):  # allow ignoring of field checks
             self.check_required_fields(ignore_fields=ignore_fields)
