@@ -3,8 +3,9 @@
 import logging
 
 from hdx.utilities.easy_logging import setup_logging
+from hdx.utilities.useragent import UserAgent
 
-from hdx.facades import logging_kwargs, environment_variables
+from hdx.facades import logging_kwargs
 from hdx.hdx_configuration import Configuration
 
 logger = logging.getLogger(__name__)
@@ -26,10 +27,12 @@ def facade(projectmainfn, **kwargs):
     #
     # Setting up configuration
     #
-    kwargs = environment_variables(**kwargs)
     site_url = Configuration._create(**kwargs)
 
     logger.info('--------------------------------------------------')
+    logger.info('> Using HDX Python API Library %s' % Configuration.apiversion)
     logger.info('> HDX Site: %s' % site_url)
 
+    UserAgent.user_agent = Configuration.read().user_agent
+
     projectmainfn()
